# mysqldb_rich

## 3.0
允许设置charset

## 2.9
表结构更新时支持uni_key

## 2.6
fix execute_logic_non bug

## 2.5
fix execute_multi_select bug

## 2.4
DB add function link

## 2.2
fix db2.DB not commit

## 2.1
解决两个连接使用不同数据库问题

## 2.0
AUTO_CLOSE default is False

## 1.9
add execute_select_left

## 1.8
add RichDB

## 1.6
fix bug in TableDB

## 0.1
rich operation for mysql 